==> jc-1.4.0.tar.gz: java/util/Collections__24SynchronizedSortedMap.h <==
// final class java.util.Collections$SynchronizedSortedMap

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4c724ebd552bdb5 java_util_Collections__24SynchronizedMap
// @dep_class 1b977fc71051c69 java_util_Collections__24SynchronizedSortedMap

// header file dependencies
// @dep_header java_util_Collections__24SynchronizedMap

#include "java/util/Collections__24SynchronizedMap.h"

#ifndef _JC_java_util_Collections__24SynchronizedSortedMap_H_
#define _JC_java_util_Collections__24SynchronizedSortedMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Comparator$object;
struct _jc_java_util_SortedMap$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedSortedMap$sub_refs	_jc_java_util_Collections__24SynchronizedSortedMap$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedMap$sub_nonrefs	_jc_java_util_Collections__24SynchronizedSortedMap$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedMap$refs	_jc_java_util_Collections__24SynchronizedSortedMap$refs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedMap$nonrefs	_jc_java_util_Collections__24SynchronizedSortedMap$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedMap$object	_jc_java_util_Collections__24SynchronizedSortedMap$object;

typedef struct _jc_java_util_Collections__24SynchronizedSortedMap$fields_struct	_jc_java_util_Collections__24SynchronizedSortedMap$fields_struct;
typedef const struct _jc_java_util_Collections__24SynchronizedSortedMap$vmethods	_jc_java_util_Collections__24SynchronizedSortedMap$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedSortedMap$vtable	_jc_java_util_Collections__24SynchronizedSortedMap$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedSortedMap$vtype	_jc_java_util_Collections__24SynchronizedSortedMap$vtype;

// Class fields structure
struct _jc_java_util_Collections__24SynchronizedSortedMap$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24SynchronizedSortedMap$fields_struct _jc_java_util_Collections__24SynchronizedSortedMap$class_fields;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedSortedMap$method$_init$d91895d33d6ba594(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);
extern void _jc_java_util_Collections__24SynchronizedSortedMap$method$_init$b8b18dc0609f98ee(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedMap$method$comparator$685c966d9d487177(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedSortedMap$method$firstKey$1d795f88ad41d60f(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *);
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedMap$method$headMap$cd1c0e4f2149ad0e(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedSortedMap$method$lastKey$5e1b1339ae1f923e(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *);
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedMap$method$subMap$9075b8398fbdea53(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedMap$method$tailMap$8556654599c88ce2(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedMap$method_info$comparator$685c966d9d487177;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedMap$method_info$firstKey$1d795f88ad41d60f;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedMap$method_info$headMap$cd1c0e4f2149ad0e;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedMap$method_info$lastKey$5e1b1339ae1f923e;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedMap$method_info$subMap$9075b8398fbdea53;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedMap$method_info$tailMap$8556654599c88ce2;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedSortedMap$vmethods {
	struct _jc_object	*(*comparator$685c966d9d487177)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *);
	struct _jc_java_lang_Object$object	*(*firstKey$1d795f88ad41d60f)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *);
	struct _jc_object	*(*headMap$cd1c0e4f2149ad0e)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*lastKey$5e1b1339ae1f923e)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *);
	struct _jc_object	*(*subMap$9075b8398fbdea53)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*tailMap$8556654599c88ce2)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedSortedMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedMap$vmethods	java_util_Collections__24SynchronizedMap;
	_jc_java_util_Collections__24SynchronizedSortedMap$vmethods	java_util_Collections__24SynchronizedSortedMap;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedSortedMap$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedSortedMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedSortedMap$sub_refs {
	struct _jc_object	*sm;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedSortedMap$refs {
    _jc_java_util_Collections__24SynchronizedSortedMap$sub_refs	java_util_Collections__24SynchronizedSortedMap;
    _jc_java_util_Collections__24SynchronizedMap$sub_refs	java_util_Collections__24SynchronizedMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedSortedMap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedSortedMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedMap$sub_nonrefs	java_util_Collections__24SynchronizedMap;
    _jc_java_util_Collections__24SynchronizedSortedMap$sub_nonrefs	java_util_Collections__24SynchronizedSortedMap;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedSortedMap$object {
	_jc_java_util_Collections__24SynchronizedSortedMap$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedSortedMap$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedSortedMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedSortedMap$vtype _jc_java_util_Collections__24SynchronizedSortedMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedSortedMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedSortedMap$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedSortedMap_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24SynchronizedSortedMap.h <==
// final class java.util.Collections$SynchronizedSortedMap

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4c724ebd552bdb5 java_util_Collections__24SynchronizedMap
// @dep_class 1b977fc71051c69 java_util_Collections__24SynchronizedSortedMap

// header file dependencies
// @dep_header java_util_Collections__24SynchronizedMap

#include "java/util/Collections__24SynchronizedMap.h"

#ifndef _JC_java_util_Collections__24SynchronizedSortedMap_H_
#define _JC_java_util_Collections__24SynchronizedSortedMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Comparator$object;
struct _jc_java_util_SortedMap$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedSortedMap$sub_refs	_jc_java_util_Collections__24SynchronizedSortedMap$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedMap$sub_nonrefs	_jc_java_util_Collections__24SynchronizedSortedMap$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedMap$refs	_jc_java_util_Collections__24SynchronizedSortedMap$refs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedMap$nonrefs	_jc_java_util_Collections__24SynchronizedSortedMap$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedMap$object	_jc_java_util_Collections__24SynchronizedSortedMap$object;

typedef struct _jc_java_util_Collections__24SynchronizedSortedMap$fields_struct	_jc_java_util_Collections__24SynchronizedSortedMap$fields_struct;
typedef const struct _jc_java_util_Collections__24SynchronizedSortedMap$vmethods	_jc_java_util_Collections__24SynchronizedSortedMap$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedSortedMap$vtable	_jc_java_util_Collections__24SynchronizedSortedMap$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedSortedMap$vtype	_jc_java_util_Collections__24SynchronizedSortedMap$vtype;

// Class fields structure
struct _jc_java_util_Collections__24SynchronizedSortedMap$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24SynchronizedSortedMap$fields_struct _jc_java_util_Collections__24SynchronizedSortedMap$class_fields;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedSortedMap$method$_init$d91895d33d6ba594(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_util_Collections__24SynchronizedSortedMap$method$_init$b8b18dc0609f98ee(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedMap$method$comparator$685c966d9d487177(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedSortedMap$method$firstKey$1d795f88ad41d60f(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedMap$method$headMap$cd1c0e4f2149ad0e(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedSortedMap$method$lastKey$5e1b1339ae1f923e(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedMap$method$subMap$9075b8398fbdea53(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedMap$method$tailMap$8556654599c88ce2(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedMap$method_info$comparator$685c966d9d487177;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedMap$method_info$firstKey$1d795f88ad41d60f;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedMap$method_info$headMap$cd1c0e4f2149ad0e;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedMap$method_info$lastKey$5e1b1339ae1f923e;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedMap$method_info$subMap$9075b8398fbdea53;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedMap$method_info$tailMap$8556654599c88ce2;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedSortedMap$vmethods {
	struct _jc_object	*(*comparator$685c966d9d487177)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*firstKey$1d795f88ad41d60f)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*headMap$cd1c0e4f2149ad0e)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*lastKey$5e1b1339ae1f923e)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*subMap$9075b8398fbdea53)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*tailMap$8556654599c88ce2)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedSortedMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedMap$vmethods	java_util_Collections__24SynchronizedMap;
	_jc_java_util_Collections__24SynchronizedSortedMap$vmethods	java_util_Collections__24SynchronizedSortedMap;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedSortedMap$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedSortedMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedSortedMap$sub_refs {
	struct _jc_object	*sm;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedSortedMap$refs {
    _jc_java_util_Collections__24SynchronizedSortedMap$sub_refs	java_util_Collections__24SynchronizedSortedMap;
    _jc_java_util_Collections__24SynchronizedMap$sub_refs	java_util_Collections__24SynchronizedMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedSortedMap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedSortedMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedMap$sub_nonrefs	java_util_Collections__24SynchronizedMap;
    _jc_java_util_Collections__24SynchronizedSortedMap$sub_nonrefs	java_util_Collections__24SynchronizedSortedMap;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedSortedMap$object {
	_jc_java_util_Collections__24SynchronizedSortedMap$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedSortedMap$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedSortedMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedSortedMap$vtype _jc_java_util_Collections__24SynchronizedSortedMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedSortedMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedSortedMap$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedSortedMap_H_ */
